@@ -1,6 +1,6 @@
 /* safe-alloc.c: safer memory allocation
 
-   Copyright (C) 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 2009-2017 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published by the
@@ -13,7 +13,7 @@
    GNU Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Daniel Berrange <berrange@redhat.com>, 2008 */
 
@@ -22,30 +22,13 @@
 /* Specification.  */
 #include "safe-alloc.h"
 
+#include "xalloc-oversized.h"
+
 #include <stdlib.h>
 #include <stddef.h>
 #include <errno.h>
 
 
-/* Return 1 if an array of N objects, each of size S, cannot exist due
-   to size arithmetic overflow.  S must be positive and N must be
-   nonnegative.  This is a macro, not a function, so that it
-   works correctly even when SIZE_MAX < N.
-
-   By gnulib convention, SIZE_MAX represents overflow in size
-   calculations, so the conservative dividend to use here is
-   SIZE_MAX - 1, since SIZE_MAX might represent an overflowed value.
-   However, malloc (SIZE_MAX) fails on all known hosts where
-   sizeof (ptrdiff_t) <= sizeof (size_t), so do not bother to test for
-   exactly-SIZE_MAX allocations on such hosts; this avoids a test and
-   branch when S is known to be 1.
-
-   This is the same as xalloc_oversized from xalloc.h
-*/
-#define safe_alloc_oversized(n, s)                                      \
-  ((size_t) (sizeof (ptrdiff_t) <= sizeof (size_t) ? -1 : -2) / (s) < (n))
-
-
 /**
  * safe_alloc_alloc_n:
  * @ptrptr: pointer to pointer for address of allocated memory
@@ -68,7 +51,7 @@ safe_alloc_alloc_n (void *ptrptr, size_t size, size_t count, int zeroed)
       return 0;
     }
 
-  if (safe_alloc_oversized (count, size))
+  if (xalloc_oversized (count, size))
     {
       errno = ENOMEM;
       return -1;
@@ -108,7 +91,7 @@ safe_alloc_realloc_n (void *ptrptr, size_t size, size_t count)
       *(void **) ptrptr = NULL;
       return 0;
     }
-  if (safe_alloc_oversized (count, size))
+  if (xalloc_oversized (count, size))
     {
       errno = ENOMEM;
       return -1;
