@@ -92,7 +92,7 @@ static struct value *lns_square(struct info *info, struct value *l1,
     assert(l1->tag == V_LENS);
     assert(l2->tag == V_LENS);
     assert(l3->tag == V_LENS);
-    int check = info->error->aug->flags & AUG_TYPE_CHECK;
+    int check = typecheck_p(info);
 
     return lns_make_square(ref(info), ref(l1->lens), ref(l2->lens), ref(l3->lens), check);
 }
@@ -187,7 +187,7 @@ static struct value *lens_get(struct info *info, struct value *l,
     struct value *v;
     const char *text = str->string->str;
 
-    struct tree *tree = lns_get(info, l->lens, text, &err);
+    struct tree *tree = lns_get(info, l->lens, text, 0, &err);
     if (err == NULL && ! HAS_ERR(info)) {
         v = make_value(V_TREE, ref(info));
         v->origin = make_tree_origin(tree);
@@ -222,7 +222,7 @@ static struct value *lens_put(struct info *info, struct value *l,
 
     init_memstream(&ms);
     lns_put(info, ms.stream, l->lens, tree->origin->children,
-            str->string->str, &err);
+            str->string->str, 0, &err);
     close_memstream(&ms);
 
     if (err == NULL && ! HAS_ERR(info)) {
@@ -467,7 +467,7 @@ static struct value *lns_check_rec_glue(struct info *info,
                                         struct value *l, struct value *r) {
     assert(l->tag == V_LENS);
     assert(r->tag == V_LENS);
-    int check = info->error->aug->flags & AUG_TYPE_CHECK;
+    int check = typecheck_p(info);
 
     return lns_check_rec(info, l->lens, r->lens, check);
 }
