@@ -294,6 +294,7 @@ static void func_regexp(struct state *state, int nargs);
 static void func_regexp_flag(struct state *state, int nargs);
 static void func_glob(struct state *state, int nargs);
 static void func_int(struct state *state, int nargs);
+static void func_not(struct state *state, int nargs);
 
 static const enum type arg_types_nodeset[] = { T_NODESET };
 static const enum type arg_types_string[] = { T_STRING };
@@ -334,7 +335,9 @@ static const struct func builtin_funcs[] = {
     { .name = "int", .arity = 1, .type = T_NUMBER,
       .arg_types = arg_types_nodeset, .impl = func_int },
     { .name = "int", .arity = 1, .type = T_NUMBER,
-      .arg_types = arg_types_bool, .impl = func_int }
+      .arg_types = arg_types_bool, .impl = func_int },
+    { .name = "not", .arity = 1, .type = T_BOOLEAN,
+      .arg_types = arg_types_bool, .impl = func_not }
 };
 
 #define RET_ON_ERROR                                                    \
@@ -716,6 +719,16 @@ static void func_int(struct state *state, int nargs) {
     push_value(vind, state);
 }
 
+static void func_not(struct state *state, int nargs) {
+    ensure_arity(1, 1);
+    RET_ON_ERROR;
+
+    struct value *v = pop_value(state);
+    if (v->tag == T_BOOLEAN) {
+        push_boolean_value(! v->boolval, state);
+    }
+}
+
 static struct regexp *
 nodeset_as_regexp(struct info *info, struct nodeset *ns, int glob, int nocase) {
     struct regexp *result = NULL;
@@ -1140,6 +1153,8 @@ static bool eval_pred(struct expr *expr, struct state *state) {
         return (state->ctx_pos == v->number);
     case T_NODESET:
         return v->nodeset->used > 0;
+    case T_STRING:
+        return streqv(state->ctx->value, v->string);
     default:
         assert(0);
         return false;
@@ -1362,7 +1377,7 @@ static void eval_filter(struct expr *expr, struct state *state) {
 }
 
 static struct value *lookup_var(const char *ident,
-                                struct pathx_symtab *symtab) {
+                                const struct pathx_symtab *symtab) {
     list_for_each(tab, symtab) {
         if (STREQ(ident, tab->name))
             return tab->value;
@@ -1421,7 +1436,7 @@ static void check_preds(struct pred *pred, struct state *state) {
         check_expr(e, state);
         RET_ON_ERROR;
         if (e->type != T_NODESET && e->type != T_NUMBER &&
-            e->type != T_BOOLEAN) {
+            e->type != T_BOOLEAN && e->type != T_STRING) {
             STATE_ERROR(state, PATHX_ETYPE);
             return;
         }
@@ -3018,6 +3033,16 @@ int pathx_symtab_assign_tree(struct pathx_symtab **symtab,
     return -1;
 }
 
+int
+pathx_symtab_count(const struct pathx_symtab *symtab, const char *name) {
+    struct value *v = lookup_var(name, symtab);
+
+    if (v == NULL || v->tag != T_NODESET)
+        return -1;
+
+    return v->nodeset->used;
+}
+
 struct tree *
 pathx_symtab_get_tree(struct pathx_symtab *symtab,
                       const char *name, int i) {
