@@ -1,4 +1,4 @@
-#! /bin/bash
+#!/bin/sh
 
 # Check that saving preserves mode and ownership; for this test to make
 # much sense (if any) the user running it should have at least one
@@ -13,7 +13,7 @@ mkdir -p $(dirname $hosts)
 }
 
 stat_inode() {
-ls -il $1 | cut -d ' ' -f 1
+ls -il $1 | awk '{ print $1 }'
 }
 
 AUGTOOL="augtool --nostdinc -r $root -I $abs_top_srcdir/lenses"
@@ -26,6 +26,7 @@ group=$(groups | tr ' ' '\n' | tail -1)
 chgrp $group $hosts
 
 [ -x /usr/bin/chcon ] && selinux=yes || selinux=no
+[ x$SKIP_TEST_PRESERVE_SELINUX = x1 ] && selinux=no
 if [ $selinux = yes ] ; then
   /usr/bin/chcon -t etc_t $hosts > /dev/null 2>/dev/null || selinux=no
 fi
@@ -59,9 +60,12 @@ if [ $selinux = yes -a xetc_t != "x$act_con" ] ; then
     exit 1
 fi
 
-# Check that we create new files without error
+# Check that we create new files without error and with permissions implied
+# from the umask
 init_dirs
 
+oldumask=$(umask)
+umask 0002
 $AUGTOOL > /dev/null <<EOF
 set /files/etc/hosts/1/ipaddr 127.0.0.1
 set /files/etc/hosts/1/canonical host.example.com
@@ -71,6 +75,16 @@ if [ $? != 0 ] ; then
     echo "augtool failed on new file"
     exit 1
 fi
+if [ ! -e $hosts ]; then
+    echo "augtool didn't create new /etc/hosts file"
+    exit 1
+fi
+act_mode=$(ls -l $hosts | cut -b 1-10)
+if [ x-rw-rw-r-- != "x$act_mode" ] ; then
+    echo "Expected mode 0664 due to $(umask) umask but got $act_mode"
+    exit 1
+fi
+umask $oldumask
 
 # Check that we create new files without error when backups are requested
 init_dirs
